.. Ultrasequence documentation master file, created by
   sphinx-quickstart on Wed Apr 18 23:51:06 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Ultrasequence's documentation!
=========================================

.. toctree::
   :maxdepth: 2

   readme
   ultrasequence


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
